[![Build Status](https://travis-ci.org/dutradda/myreco.svg?branch=master)](https://travis-ci.org/dutradda/myreco)
[![Coverage Status](https://coveralls.io/repos/github/dutradda/myreco/badge.svg?branch=master)](https://coveralls.io/github/dutradda/myreco?branch=master)

# myreco
My Recommendations - A Restful recommendations service
